# -*- coding: utf-8 -*-
#
# Socratic - very simple question-answer dialogue system based on python generators.
#
# Daniil Volynkin
# foxezzz@gmail.com
#
# License: MIT
#

__title__ = 'socratic'
__license__ = 'MIT'
__version__ = '0.1.1'
__author__ = 'Daniil Volynkin'
__contact__ = 'foxezzz@gmail.com'
__url__ = 'https://github.com/dvvolynkin/socratic'
__description__ = (
    'Socratic - simple question-answer dialog system.'
)
